"""
backend_agent_output automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent
from .backend_agent_content_binary import BackendAgentContentBinary
from .backend_agent_content_choice import BackendAgentContentChoice
from .backend_agent_content_object import BackendAgentContentObject
from .backend_agent_content_text import BackendAgentContentText
from .backend_agent_content_tool_call import BackendAgentContentToolCall


# This object represents an agent output
class BackendAgentOutput(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    output: Annotated[Union["BackendAgentContentBinary", "BackendAgentContentChoice", "BackendAgentContentObject", "BackendAgentContentText", "BackendAgentContentToolCall"], Field(discriminator="type")] = Field(alias="output")
    pass


