"""
consumer_user_password_reset automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerUserPasswordReset(BaseModel):
    token: Optional[str] = Field(default=None, alias="token")
    new_password: Optional[str] = Field(default=None, alias="newPassword")
    pass


