"""
backend_agent_content_tool_call automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent
from .backend_agent_content_tool_call_function import BackendAgentContentToolCallFunction


# Tool call agent message
class BackendAgentContentToolCall(BackendAgentContent):
    type: Literal["tool_call"] = Field(alias="type")
    functions: Optional[List[BackendAgentContentToolCallFunction]] = Field(default=None, alias="functions")
    pass


