"""
backend_test automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_test_config import BackendTestConfig


# This object represents a test. A test helps to verify that all operations work as expected
class BackendTest(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    operation_name: Optional[str] = Field(default=None, alias="operationName")
    message: Optional[str] = Field(default=None, alias="message")
    response: Optional[str] = Field(default=None, alias="response")
    config: Optional[BackendTestConfig] = Field(default=None, alias="config")
    pass


