"""
backend_dashboard automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_statistic_chart import BackendStatisticChart


# Represents an object containing all widget data for the dashboard
class BackendDashboard(BaseModel):
    errors_per_operation: Optional[BackendStatisticChart] = Field(default=None, alias="errorsPerOperation")
    incoming_requests: Optional[BackendStatisticChart] = Field(default=None, alias="incomingRequests")
    incoming_transactions: Optional[BackendStatisticChart] = Field(default=None, alias="incomingTransactions")
    most_used_operations: Optional[BackendStatisticChart] = Field(default=None, alias="mostUsedOperations")
    time_per_operation: Optional[BackendStatisticChart] = Field(default=None, alias="timePerOperation")
    test_coverage: Optional[BackendStatisticChart] = Field(default=None, alias="testCoverage")
    most_used_activities: Optional[BackendStatisticChart] = Field(default=None, alias="mostUsedActivities")
    activities_per_user: Optional[BackendStatisticChart] = Field(default=None, alias="activitiesPerUser")
    user_registrations: Optional[BackendStatisticChart] = Field(default=None, alias="userRegistrations")
    pass


