"""
backend_page automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_metadata import CommonMetadata


# This object represents a page at the developer portal
class BackendPage(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    title: Optional[str] = Field(default=None, alias="title")
    slug: Optional[str] = Field(default=None, alias="slug")
    content: Optional[str] = Field(default=None, alias="content")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass


