"""
backend_file automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime


# This object represents a file on the filesystem
class BackendFile(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    content_type: Optional[str] = Field(default=None, alias="contentType")
    checksum: Optional[str] = Field(default=None, alias="checksum")
    last_modified: Optional[datetime.datetime] = Field(default=None, alias="lastModified")
    pass


