"""
backend_taxonomy_move automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# Moves the provided objects to a taxonomy
class BackendTaxonomyMove(BaseModel):
    operations: Optional[List[int]] = Field(default=None, alias="operations")
    actions: Optional[List[int]] = Field(default=None, alias="actions")
    events: Optional[List[int]] = Field(default=None, alias="events")
    cronjobs: Optional[List[int]] = Field(default=None, alias="cronjobs")
    triggers: Optional[List[int]] = Field(default=None, alias="triggers")
    pass


