"""
backend_agent_message_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_collection import CommonCollection
from .backend_agent_message import BackendAgentMessage


# Represents a collection of agent messages
class BackendAgentMessageCollection(CommonCollection[BackendAgentMessage]):
    pass


