"""
backend_scope_categories automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_scope_category import BackendScopeCategory


class BackendScopeCategories(BaseModel):
    categories: Optional[List[BackendScopeCategory]] = Field(default=None, alias="categories")
    pass


