"""
common_form_element_tag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_form_element import CommonFormElement


# Form element which represents an input tag editor to enter comma-separated values
class CommonFormElementTag(CommonFormElement):
    type: Literal["http://fusio-project.org/ns/2015/form/tag"] = Field(alias="type")
    pass


