"""
backend_firewall automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .common_metadata import CommonMetadata


# This object represents a firewall rule which blocks specific IP addresses
class BackendFirewall(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    type: Optional[int] = Field(default=None, alias="type")
    ip: Optional[str] = Field(default=None, alias="ip")
    expire: Optional[datetime.datetime] = Field(default=None, alias="expire")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass


