"""
common_form_element automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# Form base element
class CommonFormElement(BaseModel):
    element: Optional[str] = Field(default=None, alias="element")
    name: Optional[str] = Field(default=None, alias="name")
    title: Optional[str] = Field(default=None, alias="title")
    help: Optional[str] = Field(default=None, alias="help")
    pass


