"""
marketplace_bundle_trigger automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class MarketplaceBundleTrigger(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    event: Optional[str] = Field(default=None, alias="event")
    action: Optional[str] = Field(default=None, alias="action")
    pass


