"""
BackendConnectionAgentTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_agent_input import BackendAgentInput
from .backend_agent_output import BackendAgentOutput
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendConnectionAgentTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def send(self, connection_id: str, payload: BackendAgentInput) -> BackendAgentOutput:
        """
        Sends a message to an agent
        """
        try:
            path_params = {}
            path_params['connection_id'] = connection_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url('/backend/connection/:connection_id/agent', path_params)

            options = {}
            options['headers'] = {}
            options['params'] = self.parser.query(query_params, query_struct_names)

            options['json'] = payload.model_dump(by_alias=True)

            options['headers']['Content-Type'] = 'application/json'

            response = self.http_client.request('POST', url, **options)

            if response.status_code >= 200 and response.status_code < 300:
                data = BackendAgentOutput.model_validate_json(json_data=response.content)

                return data

            statusCode = response.status_code
            if statusCode >= 0 and statusCode <= 999:
                data = CommonMessage.model_validate_json(json_data=response.content)

                raise CommonMessageException(data)

            raise sdkgen.UnknownStatusCodeException('The server returned an unknown status code: ' + str(statusCode))
        except RequestException as e:
            raise sdkgen.ClientException('An unknown error occurred: ' + str(e))



