"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_action_index_entry import BackendActionIndexEntry


# Contains all possible classes which can be used at an action as class
class BackendActionIndex(BaseModel):
    actions: Optional[List[BackendActionIndexEntry]] = Field(default=None, alias="actions")
    pass


