"""
backend_scope_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class BackendScopeOperation(BaseModel):
    operation_id: Optional[int] = Field(default=None, alias="operationId")
    allow: Optional[bool] = Field(default=None, alias="allow")
    pass


