"""
backend_rate_allocation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a rate allocation, in case a request matches it gets assigned to the attached rate
class BackendRateAllocation(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    operation_id: Optional[int] = Field(default=None, alias="operationId")
    user_id: Optional[int] = Field(default=None, alias="userId")
    plan_id: Optional[int] = Field(default=None, alias="planId")
    app_id: Optional[int] = Field(default=None, alias="appId")
    authenticated: Optional[bool] = Field(default=None, alias="authenticated")
    pass


