"""
backend_database_table_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# This object represents a table index on a relational database
class BackendDatabaseTableIndex(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    unique: Optional[bool] = Field(default=None, alias="unique")
    columns: Optional[List[str]] = Field(default=None, alias="columns")
    pass


