"""
marketplace_bundle_config automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .marketplace_bundle_action import MarketplaceBundleAction
from .marketplace_bundle_schema import MarketplaceBundleSchema
from .marketplace_bundle_event import MarketplaceBundleEvent
from .marketplace_bundle_cronjob import MarketplaceBundleCronjob
from .marketplace_bundle_trigger import MarketplaceBundleTrigger


class MarketplaceBundleConfig(BaseModel):
    actions: Optional[List[MarketplaceBundleAction]] = Field(default=None, alias="actions")
    schemas: Optional[List[MarketplaceBundleSchema]] = Field(default=None, alias="schemas")
    events: Optional[List[MarketplaceBundleEvent]] = Field(default=None, alias="events")
    cronjobs: Optional[List[MarketplaceBundleCronjob]] = Field(default=None, alias="cronjobs")
    triggers: Optional[List[MarketplaceBundleTrigger]] = Field(default=None, alias="triggers")
    pass


