"""
backend_generator_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_generator_provider_config import BackendGeneratorProviderConfig


class BackendGeneratorProvider(BaseModel):
    path: Optional[str] = Field(default=None, alias="path")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    public: Optional[bool] = Field(default=None, alias="public")
    config: Optional[BackendGeneratorProviderConfig] = Field(default=None, alias="config")
    pass


