"""
backend_agent_content_object automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent


# Structured agent message
class BackendAgentContentObject(BackendAgentContent):
    type: Literal["object"] = Field(alias="type")
    payload: Optional[Any] = Field(default=None, alias="payload")
    pass


