"""
backend_schema_commit automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .backend_user import BackendUser
from .backend_schema_source import BackendSchemaSource


# A schema commit which represents a change in the schema source
class BackendSchemaCommit(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    user: Optional[BackendUser] = Field(default=None, alias="user")
    commit_hash: Optional[str] = Field(default=None, alias="commitHash")
    schema_: Optional[BackendSchemaSource] = Field(default=None, alias="schema")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass


