"""
marketplace_object automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .marketplace_user import MarketplaceUser


# Base class of all objects on the marketplace
class MarketplaceObject(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    author: Optional[MarketplaceUser] = Field(default=None, alias="author")
    version: Optional[str] = Field(default=None, alias="version")
    icon: Optional[str] = Field(default=None, alias="icon")
    summary: Optional[str] = Field(default=None, alias="summary")
    description: Optional[str] = Field(default=None, alias="description")
    cost: Optional[int] = Field(default=None, alias="cost")
    update_date: Optional[datetime.datetime] = Field(default=None, alias="updateDate")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass


