"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerAuthorizeResponse(BaseModel):
    type: Optional[str] = Field(default=None, alias="type")
    code: Optional[str] = Field(default=None, alias="code")
    error: Optional[str] = Field(default=None, alias="error")
    state: Optional[str] = Field(default=None, alias="state")
    redirect_uri: Optional[str] = Field(default=None, alias="redirectUri")
    pass


