"""
common_form_element_select automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .common_form_element import CommonFormElement
from .common_form_element_select_option import CommonFormElementSelectOption


# Form element which represents a select element
class CommonFormElementSelect(CommonFormElement):
    type: Literal["http://fusio-project.org/ns/2015/form/select"] = Field(alias="type")
    options: Optional[List[CommonFormElementSelectOption]] = Field(default=None, alias="options")
    pass


