"""
backend_test_config automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_action_execute_request import BackendActionExecuteRequest


class BackendTestConfig(BackendActionExecuteRequest):
    pass


