"""
backend_agent_content_binary automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_content import BackendAgentContent


# Binary agent message
class BackendAgentContentBinary(BackendAgentContent):
    type: Literal["binary"] = Field(alias="type")
    mime: Optional[str] = Field(default=None, alias="mime")
    data: Optional[str] = Field(default=None, alias="data")
    pass


