"""
backend_identity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_identity_config import BackendIdentityConfig


# This object represents an identity which allows to authenticate with a remote identity provider
class BackendIdentity(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app_id: Optional[int] = Field(default=None, alias="appId")
    role_id: Optional[int] = Field(default=None, alias="roleId")
    name: Optional[str] = Field(default=None, alias="name")
    icon: Optional[str] = Field(default=None, alias="icon")
    class_: Optional[str] = Field(default=None, alias="class")
    config: Optional[BackendIdentityConfig] = Field(default=None, alias="config")
    allow_create: Optional[bool] = Field(default=None, alias="allowCreate")
    pass


