"""
BackendMarketplaceTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List
from typing import Dict
from typing import Any
from urllib.parse import parse_qs

from .backend_marketplace_action_tag import BackendMarketplaceActionTag
from .backend_marketplace_app_tag import BackendMarketplaceAppTag
from .backend_marketplace_bundle_tag import BackendMarketplaceBundleTag

class BackendMarketplaceTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def action(self) -> BackendMarketplaceActionTag:
        return BackendMarketplaceActionTag(
            self.http_client,
            self.parser
        )

    def app(self) -> BackendMarketplaceAppTag:
        return BackendMarketplaceAppTag(
            self.http_client,
            self.parser
        )

    def bundle(self) -> BackendMarketplaceBundleTag:
        return BackendMarketplaceBundleTag(
            self.http_client,
            self.parser
        )


