"""
backend_agent_tools automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_agent_tool import BackendAgentTool


# Represents a collection of available tools
class BackendAgentTools(BaseModel):
    tools: Optional[List[BackendAgentTool]] = Field(default=None, alias="tools")
    pass


