"""
consumer_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerWebhookResponse(BaseModel):
    status: Optional[int] = Field(default=None, alias="status")
    code: Optional[int] = Field(default=None, alias="code")
    attempts: Optional[str] = Field(default=None, alias="attempts")
    execute_date: Optional[str] = Field(default=None, alias="executeDate")
    pass


