"""
backend_agent_content automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


# Agent message
class BackendAgentContent(BaseModel):
    type: str = Field(alias="type")
    metadata: Optional[Dict[str, Any]] = Field(default=None, alias="metadata")
    pass


