"""
backend_bundle automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_bundle_config import BackendBundleConfig


# This object represents a bundle which contains action, schema, event, cronjob and trigger configurations from you local instance
class BackendBundle(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    version: Optional[str] = Field(default=None, alias="version")
    icon: Optional[str] = Field(default=None, alias="icon")
    summary: Optional[str] = Field(default=None, alias="summary")
    description: Optional[str] = Field(default=None, alias="description")
    cost: Optional[int] = Field(default=None, alias="cost")
    config: Optional[BackendBundleConfig] = Field(default=None, alias="config")
    pass


