"""
backend_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
from .backend_schema_source import BackendSchemaSource
from .common_metadata import CommonMetadata


# This object represents a schema to describe a JSON payload
class BackendSchema(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    source: Optional[BackendSchemaSource] = Field(default=None, alias="source")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass


