"""
consumer_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal
import datetime
from .consumer_plan import ConsumerPlan


class ConsumerTransaction(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    user_id: Optional[int] = Field(default=None, alias="userId")
    plan_id: Optional[int] = Field(default=None, alias="planId")
    plan: Optional[ConsumerPlan] = Field(default=None, alias="plan")
    transaction_id: Optional[str] = Field(default=None, alias="transactionId")
    amount: Optional[float] = Field(default=None, alias="amount")
    points: Optional[float] = Field(default=None, alias="points")
    period_start: Optional[datetime.datetime] = Field(default=None, alias="periodStart")
    period_end: Optional[datetime.datetime] = Field(default=None, alias="periodEnd")
    insert_date: Optional[datetime.datetime] = Field(default=None, alias="insertDate")
    pass


