"""
consumer_token_access_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler, Tag
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Annotated, Union, Literal


class ConsumerTokenAccessToken(BaseModel):
    access_token: Optional[str] = Field(default=None, alias="access_token")
    token_type: Optional[str] = Field(default=None, alias="token_type")
    expires_in: Optional[int] = Field(default=None, alias="expires_in")
    refresh_token: Optional[str] = Field(default=None, alias="refresh_token")
    scope: Optional[str] = Field(default=None, alias="scope")
    pass


